@@ -1,5 +1,4 @@
-from ._rcca import rCCA, CCA, PLS
-from ._gcca import GCCA, KGCCA
+from cca_zoo.models._multiview import MCCA, KCCA, GCCA, KGCCA, TCCA, KTCCA
 from ._iterative import (
     PLS_ALS,
     SCCA_PMD,
@@ -10,11 +9,10 @@ from ._iterative import (
     SCCA_Span,
     SWCCA,
 )
-from ._mcca import MCCA, KCCA
 from ._ncca import NCCA
 from ._partialcca import PartialCCA
 from ._prcca import PRCCA, GRCCA
-from ._tcca import TCCA, KTCCA
+from ._rcca import rCCA, CCA, PLS
 
 __all__ = [
     "GCCA",
